@@ -191,19 +191,24 @@ extern "C" {
     
     
     typedef struct _CNearTreeNode {
-        size_t           m_indexLeft;    /* index of left coords in m_CoordStore  
-         and of left object in m_ObjectStore     */
-        size_t           m_indexRight;   /* index of right coords in m_CoordStore 
-         and of right object in m_ObjectStore     */
-        double           m_dMaxLeft;     /* longest distance from the left object
-         to anything below it in the tree            */
-        double           m_dMaxRight;    /* longest distance from the right object 
-         to anything below it in the tree            */
+        size_t           m_indexLeft;     /* index of left coords in m_CoordStore  
+                                             and of left object in m_ObjectStore   */
+        size_t           m_indexRight;    /* index of right coords in m_CoordStore 
+                                             and of right object in m_ObjectStore  */
+        double           m_dMaxLeft;      /* longest distance from the left object
+                                             to anything below it in the tree      */
+        double           m_dMaxRight;     /* longest distance from the right object 
+                                             to anything below it in the tree      */
         struct _CNearTreeNode CNEARTREE_FAR * m_pLeftBranch;  
-        /* tree descending from the left object        */
+                                          /* tree descending from the left object  */
         struct _CNearTreeNode CNEARTREE_FAR * m_pRightBranch; 
-        /* tree descending from the right object       */
-        long              m_iflags;       /* flags      */
+                                          /* tree descending from the right object */
+        long              m_iflags;       /* flags                   */
+        size_t            m_iTreeSize;    /* size of this node tree  */
+#ifdef CNEARTREE_INSTRUMENTED
+        size_t            m_Height;        /* height of this node     */
+#endif
+
     } CNearTreeNode;
     
     
@@ -573,6 +578,18 @@ extern "C" {
     
     int CNearTreeGetDepth (const CNearTreeHandle treehandle, size_t CNEARTREE_FAR * depth);
 
+    /*
+     =======================================================================
+     int CNearTreeGetHeight (const CNearTreeHandle treehandle, size_t CNEARTREE_FAR * height)
+     
+     Return the height of the tree in height, of instrumented, otherwise the depth
+     
+     =======================================================================
+     */
+    
+    
+    int CNearTreeGetHeight ( const CNearTreeHandle treehandle, size_t CNEARTREE_FAR * height );
+
     
     /*
      =======================================================================
@@ -1228,6 +1245,27 @@ extern "C" {
                                     CNearTreeHandle foundInRing,
                                     const void CNEARTREE_FAR * coord,
                                     int resetcount);
+    
+    
+    /*
+     =======================================================================
+
+     int CNearTreeSortIn(CVectorHandle metrics, 
+     CVectorHandle indices, 
+     double metric, 
+     size_t index, 
+     size_t k);
+     
+     CNearTreeSortIn inserts a new metric and index into the vectors
+     metrics and indices, sorted on non-decreasing metric,
+     with the size of the vectors capped at k, or uncapped if k = 0;
+
+     =======================================================================
+     */
+
+    int CNearTreeSortIn(CVectorHandle metrics, CVectorHandle indices, double metric, size_t index, size_t k);
+    
+    
     /*
      =======================================================================
      
