@@ -412,7 +412,7 @@ void testFindFirstObject( void )
     
     /* build the double tree starting with 1.0 */
     f[0] = 1.0;
-    while( f[0]*f[0] > 0.0 )
+    while( f[0]*f[0] > DBL_MIN )
     {
         bReturn = !CNearTreeImmediateInsert(tree,f, NULL);
         fFinal = f[0];
@@ -439,10 +439,11 @@ void testFindFirstObject( void )
         fprintf(stdout, "CNearTreeTest: testFindFirstObject: failed for double\n" );
     }
     
-    if( bReturnNear && closest[0] != fFinal )
+    if( bReturnNear && fabs(closest[0]-fFinal)> fFinal*DBL_EPSILON )
     {
         ++g_errorCount;
-        fprintf(stdout, "CNearTreeTest: testFindFirstObject: failed for double, got %g\n", closest[0] );
+        fprintf(stdout, "CNearTreeTest: testFindFirstObject: failed for double, got %g != %g, abs error %g\n", closest[0],
+                fFinal, fabs(closest[0]-fFinal));
     }
     
     /*
@@ -452,10 +453,11 @@ void testFindFirstObject( void )
     f[0] = 100.0;
     bReturnFar = !CNearTreeFarthestNeighbor(tree, &vfarthest, NULL,f);
     farthest = (double CNEARTREE_FAR *)vfarthest;
-    if( ! bReturnFar || farthest[0] != fFinal )
+    if( ! bReturnFar || fabs(farthest[0]-fFinal)> fabs(f[0]-fFinal)*DBL_EPSILON )
     {
         ++g_errorCount;
-        fprintf(stdout, "CNearTreeTest: testFindFirstObject: failed for double, got %g\n", farthest[0] );
+        fprintf(stdout, "CNearTreeTest: testFindFirstObject: failed for double, got %g != %g, abs error %g\n", farthest[0],  
+                fFinal, fabs(farthest[0]-fFinal) );
     }
     
     /*
@@ -532,6 +534,9 @@ void testFindLastObject( void )
     
     if (dbgflg) {
         size_t depth, size;
+#ifdef CNEARTREE_INSTRUMENTED
+        size_t height;
+#endif
         bResult = !(CNearTreeGetDepth(tree,&depth)) && !(CNearTreeGetSize(tree,&size));
         if (bResult) {
             fprintf(stderr,"CNearTreeTest:  testFindLastObject: depth=%lu, size=%lu\n",
@@ -539,6 +544,15 @@ void testFindLastObject( void )
         } else {
             fprintf(stderr,"CNearTreeTest:  testFindLastObject: get size and depth failed\n");
         }
+#ifdef CNEARTREE_INSTRUMENTED
+        bResult = !(CNearTreeGetDepth(tree,&height));
+        if (bResult) {
+            fprintf(stderr,"CNearTreeTest:  testFindLastObject: height=%lu\n",
+                    (unsigned long)height);
+        } else {
+            fprintf(stderr,"CNearTreeTest:  testFindLastObject: get height failed\n");
+        }
+#endif
     }
     
     
@@ -984,6 +998,9 @@ void testRandomTree1( const int nRequestedRandoms )
     
     if (dbgflg) {
         size_t depth, size;
+#ifdef CNEARTREE_INSTRUMENTED
+        size_t height;
+#endif        
         bResult = !(CNearTreeGetDepth(tree,&depth)) && !(CNearTreeGetSize(tree,&size));
         if (bResult) {
             fprintf(stderr,"CNearTreeTest:  testRandomTree1: depth=%lu, size=%lu\n",
@@ -991,6 +1008,15 @@ void testRandomTree1( const int nRequestedRandoms )
         } else {
             fprintf(stderr,"CNearTreeTest:  testRandomTree1: get size and depth failed\n");
         }
+#ifdef CNEARTREE_INSTRUMENTED
+        bResult = !(CNearTreeGetDepth(tree,&height));
+        if (bResult) {
+            fprintf(stderr,"CNearTreeTest:  testRandomTree1: height=%lu\n",
+                    (unsigned long)height);
+        } else {
+            fprintf(stderr,"CNearTreeTest:  testRandomTree1: get height failed\n");
+        }
+#endif
     }
     
     {
@@ -1124,6 +1150,9 @@ void testRandomTree1( const int nRequestedRandoms )
     
     if (dbgflg) {
         size_t depth, size;
+#ifdef CNEARTREE_INSTRUMENTED
+        size_t height;
+#endif        
         bResult = !(CNearTreeGetDepth(tree,&depth)) && !(CNearTreeGetSize(tree,&size));
         if (bResult) {
             fprintf(stderr,"CNearTreeTest:  testRandomTree1: with flip depth=%lu, size=%lu\n",
@@ -1131,6 +1160,15 @@ void testRandomTree1( const int nRequestedRandoms )
         } else {
             fprintf(stderr,"CNearTreeTest:  testRandomTree1: with flip get size and depth failed\n");
         }
+#ifdef CNEARTREE_INSTRUMENTED
+        bResult = !(CNearTreeGetDepth(tree,&height));
+        if (bResult) {
+            fprintf(stderr,"CNearTreeTest:  testRandomTree1: height=%lu\n",
+                    (unsigned long)height);
+        } else {
+            fprintf(stderr,"CNearTreeTest:  testRandomTree1: get height failed\n");
+        }
+#endif        
     }
     
     {
@@ -1547,6 +1585,9 @@ void testBackwardForward( void )
     
     if (dbgflg) {
         size_t depth, size;
+#ifdef CNEARTREE_INSTRUMENTED
+        size_t height;
+#endif
         bResult = !(CNearTreeGetDepth(tree,&depth)) && !(CNearTreeGetSize(tree,&size));
         if (bResult) {
             fprintf(stderr,"CNearTreeTest:  testBackwardForward: depth=%lu, size=%lu\n",
@@ -1554,7 +1595,15 @@ void testBackwardForward( void )
         } else {
             fprintf(stderr,"CNearTreeTest:  testBackwardForward: get size and depth failed\n");
         }
-        
+#ifdef CNEARTREE_INSTRUMENTED
+        bResult = !(CNearTreeGetDepth(tree,&height));
+        if (bResult) {
+            fprintf(stderr,"CNearTreeTest:  testBackwardForward: height=%lu\n",
+                    (unsigned long)height);
+        } else {
+            fprintf(stderr,"CNearTreeTest:  testBackwardForward: get height failed\n");
+        }
+#endif        
     }
     
     for( i=100; i<300; ++i )
@@ -1597,6 +1646,9 @@ void testBackwardForward( void )
     
     if (dbgflg) {
         size_t depth, size;
+#ifdef CNEARTREE_INSTRUMENTED
+        size_t height;
+#endif        
         bResult = !(CNearTreeGetDepth(tree,&depth)) && !(CNearTreeGetSize(tree,&size));
         if (bResult) {
             fprintf(stderr,"CNearTreeTest:  testBackwardForward: with flip depth=%lu, size=%lu\n",
@@ -1604,7 +1656,15 @@ void testBackwardForward( void )
         } else {
             fprintf(stderr,"CNearTreeTest:  testBackwardForward: with flip get size and depth failed\n");
         }
-        
+#ifdef CNEARTREE_INSTRUMENTED
+        bResult = !(CNearTreeGetDepth(tree,&height));
+        if (bResult) {
+            fprintf(stderr,"CNearTreeTest:  testBackForward: height=%lu\n",
+                    (unsigned long)height);
+        } else {
+            fprintf(stderr,"CNearTreeTest:  testBackForward: get height failed\n");
+        }
+#endif        
     }
     
     for( i=100; i<300; ++i )
@@ -1685,6 +1745,9 @@ void testDelayedInsertion( void )
         radius = 1000.0;
         if (dbgflg) {
             size_t depth, size;
+#ifdef CNEARTREE_INSTRUMENTED
+            size_t height;
+#endif
             bResult = !(CNearTreeGetDepth(tree,&depth)) && !(CNearTreeGetSize(tree,&size));
             if (bResult) {
                 fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: before CNearTreeCompleteDelayedInsert depth=%lu, size=%lu\n",
@@ -1692,7 +1755,15 @@ void testDelayedInsertion( void )
             } else {
                 fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: before CNearTreeCompleteDelayedInsert get size and depth failed\n");
             }
-            
+#ifdef CNEARTREE_INSTRUMENTED
+            bResult = !(CNearTreeGetDepth(tree,&height));
+            if (bResult) {
+                fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: height=%lu\n",
+                        (unsigned long)height);
+            } else {
+                fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: get height failed\n");
+            }
+#endif            
         }
         bResult = !CNearTreeCompleteDelayedInsert(tree);
         if (!bResult)
@@ -1702,6 +1773,9 @@ void testDelayedInsertion( void )
         }
         if (dbgflg) {
             size_t depth, size;
+#ifdef CNEARTREE_INSTRUMENTED
+            size_t height;
+#endif
             bResult = !(CNearTreeGetDepth(tree,&depth)) && !(CNearTreeGetSize(tree,&size));
             if (bResult) {
                 fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: after CNearTreeCompleteDelayedInsert depth=%lu, size=%lu\n",
@@ -1709,7 +1783,15 @@ void testDelayedInsertion( void )
             } else {
                 fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: after CNearTreeCompleteDelayedInsert get size and depth failed\n");
             }
-            
+#ifdef CNEARTREE_INSTRUMENTED
+            bResult = !(CNearTreeGetDepth(tree,&height));
+            if (bResult) {
+                fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: height=%lu\n",
+                        (unsigned long)height);
+            } else {
+                fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: get height failed\n");
+            }
+#endif            
         }
         probe[0] = 0.9;
         bResult = !CNearTreeFindInSphere(tree, radius,v,NULL,probe,1);
@@ -1781,6 +1863,9 @@ void testDelayedInsertion( void )
         radius = 1000.0;
         if (dbgflg) {
             size_t depth, size;
+#ifdef CNEARTREE_INSTRUMENTED
+            size_t height;
+#endif
             bResult = !(CNearTreeGetDepth(tree,&depth)) && !(CNearTreeGetSize(tree,&size));
             if (bResult) {
                 fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: before CNearTreeCompleteDelayedInsert with flip depth=%lu, size=%lu\n",
@@ -1788,7 +1873,15 @@ void testDelayedInsertion( void )
             } else {
                 fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: before CNearTreeCompleteDelayedInsert with flip get size and depth failed\n");
             }
-            
+#ifdef CNEARTREE_INSTRUMENTED
+            bResult = !(CNearTreeGetDepth(tree,&height));
+            if (bResult) {
+                fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: height=%lu\n",
+                        (unsigned long)height);
+            } else {
+                fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: get height failed\n");
+            }
+#endif            
         }
         bResult = !CNearTreeCompleteDelayedInsert(tree);
         if (!bResult)
@@ -1798,6 +1891,9 @@ void testDelayedInsertion( void )
         }
         if (dbgflg) {
             size_t depth, size;
+#ifdef CNEARTREE_INSTRUMENTED
+            size_t height;
+#endif
             bResult = !(CNearTreeGetDepth(tree,&depth)) && !(CNearTreeGetSize(tree,&size));
             if (bResult) {
                 fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: after CNearTreeCompleteDelayedInsert depth=%lu, size=%lu\n",
@@ -1805,6 +1901,15 @@ void testDelayedInsertion( void )
             } else {
                 fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: after CNearTreeCompleteDelayedInsert get size and depth failed\n");
             }
+#ifdef CNEARTREE_INSTRUMENTED
+            bResult = !(CNearTreeGetDepth(tree,&height));
+            if (bResult) {
+                fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: height=%lu\n",
+                        (unsigned long)height);
+            } else {
+                fprintf(stderr,"CNearTreeTest:  testDelayedInsertion: get height failed\n");
+            }
+#endif
         }
         probe[0] = 0.9;
         bResult = !CNearTreeFindInSphere(tree, radius,v,NULL,probe,1);
